# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authentication.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from . import users_pb2 as users__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='authentication.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=_b('\342?\026\n\024im.dlg.grpc.services'),
  serialized_pb=_b('\n\x14\x61uthentication.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x0busers.proto\x1a\x15scalapb/scalapb.proto\"\xcc\x02\n\x15RequestStartPhoneAuth\x12#\n\x0cphone_number\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x02 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\"\n\x0b\x64\x65vice_hash\x18\x04 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x07 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9e\x01\n\x16ResponseStartPhoneAuth\x12\x18\n\x10transaction_hash\x18\x01 \x01(\t\x12\x15\n\ris_registered\x18\x02 \x01(\x08\x12\x34\n\x0f\x61\x63tivation_type\x18\x03 \x01(\x0e\x32\x1b.dialog.PhoneActivationType:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"b\n\x1aRequestSendCodeByPhoneCall\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc5\x02\n\x15RequestStartEmailAuth\x12\x1c\n\x05\x65mail\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x02 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\"\n\x0b\x64\x65vice_hash\x18\x04 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x07 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9e\x01\n\x16ResponseStartEmailAuth\x12\x18\n\x10transaction_hash\x18\x01 \x01(\t\x12\x15\n\ris_registered\x18\x02 \x01(\x08\x12\x34\n\x0f\x61\x63tivation_type\x18\x03 \x01(\x0e\x32\x1b.dialog.EmailActivationType:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xc8\x02\n\x19RequestStartAnonymousAuth\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x02 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\"\n\x0b\x64\x65vice_hash\x18\x04 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x07 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc5\x02\n\x15RequestStartTokenAuth\x12\x1c\n\x05token\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x02 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\"\n\x0b\x64\x65vice_hash\x18\x04 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x07 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xcb\x02\n\x18RequestStartUsernameAuth\x12\x1f\n\x08username\x18\x01 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x02 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\"\n\x0b\x64\x65vice_hash\x18\x04 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12>\n\ttime_zone\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\x12*\n\x13preferred_languages\x18\x07 \x03(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"k\n\x19ResponseStartUsernameAuth\x12\x18\n\x10transaction_hash\x18\x01 \x01(\t\x12\x15\n\ris_registered\x18\x02 \x01(\x08:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"w\n\x13RequestValidateCode\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1a\n\x04\x63ode\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"Y\n\x11RequestResendCode\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x7f\n\x17RequestValidatePassword\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1e\n\x08password\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x83\x01\n\x16RequestGetOAuth2Params\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12#\n\x0credirect_url\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"J\n\x17ResponseGetOAuth2Params\x12\x10\n\x08\x61uth_url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"y\n\x15RequestCompleteOAuth2\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1a\n\x04\x63ode\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xd9\x01\n\rRequestSignUp\x12&\n\x10transaction_hash\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1b\n\x04name\x18\x02 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\'\n\x03sex\x18\x03 \x01(\x0e\x32\x0b.dialog.SexB\r\x8a\xea\x30\t\n\x07visible\x12<\n\x08password\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xc8\x01\n\x0cResponseAuth\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x0c.dialog.UserB\r\x8a\xea\x30\t\n\x07\x63ompact\x12-\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x0e.dialog.ConfigB\r\x8a\xea\x30\t\n\x07visible\x12?\n\x0b\x63onfig_hash\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x8a\x03\n\x0b\x41uthSession\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12\x36\n\x0b\x61uth_holder\x18\x02 \x01(\x0e\x32\x12.dialog.AuthHolderB\r\x8a\xea\x30\t\n\x07visible\x12\x1d\n\x06\x61pp_id\x18\x03 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12 \n\tapp_title\x18\x04 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x05 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12 \n\tauth_time\x18\x06 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\rauth_location\x18\x07 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12<\n\x08latitude\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0c\x8a\xea\x30\x08\n\x06hidden\x12=\n\tlongitude\x18\t \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0c\x8a\xea\x30\x08\n\x06hidden\"6\n\x16RequestGetAuthSessions:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"a\n\x17ResponseGetAuthSessions\x12\'\n\nuser_auths\x18\x01 \x03(\x0b\x32\x13.dialog.AuthSession:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"R\n\x17RequestTerminateSession\x12\x19\n\x02id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\";\n\x1bRequestTerminateAllSessions:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\".\n\x0eRequestSignOut:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xca\x01\n\x10\x46orceReloadField\x12\x38\n\x12\x66orceReloadDialogs\x18\x01 \x01(\x0b\x32\x1a.dialog.ForceReloadDialogsH\x00\x12:\n\x13\x66orceReloadContacts\x18\x02 \x01(\x0b\x32\x1b.dialog.ForceReloadContactsH\x00\x12\x38\n\x12\x66orceReloadHistory\x18\x03 \x01(\x0b\x32\x1a.dialog.ForceReloadHistoryH\x00\x42\x06\n\x04\x62ody\"\x14\n\x12\x46orceReloadDialogs\"\x15\n\x13\x46orceReloadContacts\"?\n\x12\x46orceReloadHistory\x12)\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.PeerB\r\x8a\xea\x30\t\n\x07visible\"Q\n\x16UpdateForceReloadState\x12\x37\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.dialog.ForceReloadFieldB\r\x8a\xea\x30\t\n\x07visible\"\x9f\x02\n\x15RequestSignInObsolete\x12\"\n\x0cphone_number\x18\x01 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1e\n\x08sms_hash\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1e\n\x08sms_code\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\"\n\x0b\x64\x65vice_hash\x18\x05 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x06 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x07 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pp_key\x18\x08 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xcf\x02\n\x15RequestSignUpObsolete\x12\"\n\x0cphone_number\x18\x01 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1e\n\x08sms_hash\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1e\n\x08sms_code\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1b\n\x04name\x18\x04 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\"\n\x0b\x64\x65vice_hash\x18\x07 \x01(\x0c\x42\r\x8a\xea\x30\t\n\x07visible\x12#\n\x0c\x64\x65vice_title\x18\x08 \x01(\tB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\t \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pp_key\x18\n \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x11\n\tis_silent\x18\x0b \x01(\x08:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9d\x01\n\x1bRequestSendAuthCodeObsolete\x12#\n\x0cphone_number\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x06\x61pp_id\x18\x02 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x03 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"f\n\x1cResponseSendAuthCodeObsolete\x12\x10\n\x08sms_hash\x18\x01 \x01(\t\x12\x15\n\ris_registered\x18\x02 \x01(\x08:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xbd\x01\n\x1bRequestSendAuthCallObsolete\x12#\n\x0cphone_number\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12\x1e\n\x08sms_hash\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x1c\n\x06\x61pp_id\x18\x03 \x01(\x05\x42\x0c\x8a\xea\x30\x08\n\x06hidden\x12\x1d\n\x07\x61pi_key\x18\x04 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06hidden:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest*v\n\x13PhoneActivationType\x12\x1f\n\x1bPHONEACTIVATIONTYPE_UNKNOWN\x10\x00\x12\x1c\n\x18PHONEACTIVATIONTYPE_CODE\x10\x01\x12 \n\x1cPHONEACTIVATIONTYPE_PASSWORD\x10\x02*\x96\x01\n\x13\x45mailActivationType\x12\x1f\n\x1b\x45MAILACTIVATIONTYPE_UNKNOWN\x10\x00\x12\x1c\n\x18\x45MAILACTIVATIONTYPE_CODE\x10\x01\x12\x1e\n\x1a\x45MAILACTIVATIONTYPE_OAUTH2\x10\x02\x12 \n\x1c\x45MAILACTIVATIONTYPE_PASSWORD\x10\x03*[\n\nAuthHolder\x12\x16\n\x12\x41UTHHOLDER_UNKNOWN\x10\x00\x12\x19\n\x15\x41UTHHOLDER_THISDEVICE\x10\x01\x12\x1a\n\x16\x41UTHHOLDER_OTHERDEVICE\x10\x02\x32\x96\x14\n\x0e\x41uthentication\x12\x82\x01\n\x0eStartPhoneAuth\x12\x1d.dialog.RequestStartPhoneAuth\x1a\x1e.dialog.ResponseStartPhoneAuth\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Authentication/StartPhoneAuth:\x01*\x12\x87\x01\n\x13SendCodeByPhoneCall\x12\".dialog.RequestSendCodeByPhoneCall\x1a\x14.dialog.ResponseVoid\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/grpc/Authentication/SendCodeByPhoneCall:\x01*\x12\x82\x01\n\x0eStartEmailAuth\x12\x1d.dialog.RequestStartEmailAuth\x1a\x1e.dialog.ResponseStartEmailAuth\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Authentication/StartEmailAuth:\x01*\x12\x84\x01\n\x12StartAnonymousAuth\x12!.dialog.RequestStartAnonymousAuth\x1a\x14.dialog.ResponseAuth\"5\x82\xd3\xe4\x93\x02/\"*/v1/grpc/Authentication/StartAnonymousAuth:\x01*\x12x\n\x0eStartTokenAuth\x12\x1d.dialog.RequestStartTokenAuth\x1a\x14.dialog.ResponseAuth\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Authentication/StartTokenAuth:\x01*\x12\x8e\x01\n\x11StartUsernameAuth\x12 .dialog.RequestStartUsernameAuth\x1a!.dialog.ResponseStartUsernameAuth\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Authentication/StartUsernameAuth:\x01*\x12r\n\x0cValidateCode\x12\x1b.dialog.RequestValidateCode\x1a\x14.dialog.ResponseAuth\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/Authentication/ValidateCode:\x01*\x12l\n\nResendCode\x12\x19.dialog.RequestResendCode\x1a\x14.dialog.ResponseVoid\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/grpc/Authentication/ResendCode:\x01*\x12~\n\x10ValidatePassword\x12\x1f.dialog.RequestValidatePassword\x1a\x14.dialog.ResponseAuth\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Authentication/ValidatePassword:\x01*\x12\x86\x01\n\x0fGetOAuth2Params\x12\x1e.dialog.RequestGetOAuth2Params\x1a\x1f.dialog.ResponseGetOAuth2Params\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/Authentication/GetOAuth2Params:\x01*\x12x\n\x0e\x43ompleteOAuth2\x12\x1d.dialog.RequestCompleteOAuth2\x1a\x14.dialog.ResponseAuth\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Authentication/CompleteOAuth2:\x01*\x12`\n\x06SignUp\x12\x15.dialog.RequestSignUp\x1a\x14.dialog.ResponseAuth\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/grpc/Authentication/SignUp:\x01*\x12\x86\x01\n\x0fGetAuthSessions\x12\x1e.dialog.RequestGetAuthSessions\x1a\x1f.dialog.ResponseGetAuthSessions\"2\x82\xd3\xe4\x93\x02,\"\'/v1/grpc/Authentication/GetAuthSessions:\x01*\x12~\n\x10TerminateSession\x12\x1f.dialog.RequestTerminateSession\x1a\x14.dialog.ResponseVoid\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Authentication/TerminateSession:\x01*\x12\x8a\x01\n\x14TerminateAllSessions\x12#.dialog.RequestTerminateAllSessions\x1a\x14.dialog.ResponseVoid\"7\x82\xd3\xe4\x93\x02\x31\",/v1/grpc/Authentication/TerminateAllSessions:\x01*\x12\x63\n\x07SignOut\x12\x16.dialog.RequestSignOut\x1a\x14.dialog.ResponseVoid\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Authentication/SignOut:\x01*\x12x\n\x0eSignInObsolete\x12\x1d.dialog.RequestSignInObsolete\x1a\x14.dialog.ResponseAuth\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Authentication/SignInObsolete:\x01*\x12x\n\x0eSignUpObsolete\x12\x1d.dialog.RequestSignUpObsolete\x1a\x14.dialog.ResponseAuth\"1\x82\xd3\xe4\x93\x02+\"&/v1/grpc/Authentication/SignUpObsolete:\x01*\x12\x9a\x01\n\x14SendAuthCodeObsolete\x12#.dialog.RequestSendAuthCodeObsolete\x1a$.dialog.ResponseSendAuthCodeObsolete\"7\x82\xd3\xe4\x93\x02\x31\",/v1/grpc/Authentication/SendAuthCodeObsolete:\x01*\x12\x8a\x01\n\x14SendAuthCallObsolete\x12#.dialog.RequestSendAuthCallObsolete\x1a\x14.dialog.ResponseVoid\"7\x82\xd3\xe4\x93\x02\x31\",/v1/grpc/Authentication/SendAuthCallObsolete:\x01*B\x19\xe2?\x16\n\x14im.dlg.grpc.servicesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,users__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_PHONEACTIVATIONTYPE = _descriptor.EnumDescriptor(
  name='PhoneActivationType',
  full_name='dialog.PhoneActivationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PHONEACTIVATIONTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONEACTIVATIONTYPE_CODE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONEACTIVATIONTYPE_PASSWORD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5694,
  serialized_end=5812,
)
_sym_db.RegisterEnumDescriptor(_PHONEACTIVATIONTYPE)

PhoneActivationType = enum_type_wrapper.EnumTypeWrapper(_PHONEACTIVATIONTYPE)
_EMAILACTIVATIONTYPE = _descriptor.EnumDescriptor(
  name='EmailActivationType',
  full_name='dialog.EmailActivationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMAILACTIVATIONTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMAILACTIVATIONTYPE_CODE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMAILACTIVATIONTYPE_OAUTH2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMAILACTIVATIONTYPE_PASSWORD', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5815,
  serialized_end=5965,
)
_sym_db.RegisterEnumDescriptor(_EMAILACTIVATIONTYPE)

EmailActivationType = enum_type_wrapper.EnumTypeWrapper(_EMAILACTIVATIONTYPE)
_AUTHHOLDER = _descriptor.EnumDescriptor(
  name='AuthHolder',
  full_name='dialog.AuthHolder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTHHOLDER_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHHOLDER_THISDEVICE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHHOLDER_OTHERDEVICE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5967,
  serialized_end=6058,
)
_sym_db.RegisterEnumDescriptor(_AUTHHOLDER)

AuthHolder = enum_type_wrapper.EnumTypeWrapper(_AUTHHOLDER)
PHONEACTIVATIONTYPE_UNKNOWN = 0
PHONEACTIVATIONTYPE_CODE = 1
PHONEACTIVATIONTYPE_PASSWORD = 2
EMAILACTIVATIONTYPE_UNKNOWN = 0
EMAILACTIVATIONTYPE_CODE = 1
EMAILACTIVATIONTYPE_OAUTH2 = 2
EMAILACTIVATIONTYPE_PASSWORD = 3
AUTHHOLDER_UNKNOWN = 0
AUTHHOLDER_THISDEVICE = 1
AUTHHOLDER_OTHERDEVICE = 2



_REQUESTSTARTPHONEAUTH = _descriptor.Descriptor(
  name='RequestStartPhoneAuth',
  full_name='dialog.RequestStartPhoneAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='dialog.RequestStartPhoneAuth.phone_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestStartPhoneAuth.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestStartPhoneAuth.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestStartPhoneAuth.device_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestStartPhoneAuth.device_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.RequestStartPhoneAuth.time_zone', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestStartPhoneAuth.preferred_languages', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=516,
)


_RESPONSESTARTPHONEAUTH = _descriptor.Descriptor(
  name='ResponseStartPhoneAuth',
  full_name='dialog.ResponseStartPhoneAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.ResponseStartPhoneAuth.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_registered', full_name='dialog.ResponseStartPhoneAuth.is_registered', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activation_type', full_name='dialog.ResponseStartPhoneAuth.activation_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=677,
)


_REQUESTSENDCODEBYPHONECALL = _descriptor.Descriptor(
  name='RequestSendCodeByPhoneCall',
  full_name='dialog.RequestSendCodeByPhoneCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestSendCodeByPhoneCall.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=679,
  serialized_end=777,
)


_REQUESTSTARTEMAILAUTH = _descriptor.Descriptor(
  name='RequestStartEmailAuth',
  full_name='dialog.RequestStartEmailAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='dialog.RequestStartEmailAuth.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestStartEmailAuth.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestStartEmailAuth.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestStartEmailAuth.device_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestStartEmailAuth.device_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.RequestStartEmailAuth.time_zone', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestStartEmailAuth.preferred_languages', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=1105,
)


_RESPONSESTARTEMAILAUTH = _descriptor.Descriptor(
  name='ResponseStartEmailAuth',
  full_name='dialog.ResponseStartEmailAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.ResponseStartEmailAuth.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_registered', full_name='dialog.ResponseStartEmailAuth.is_registered', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activation_type', full_name='dialog.ResponseStartEmailAuth.activation_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1108,
  serialized_end=1266,
)


_REQUESTSTARTANONYMOUSAUTH = _descriptor.Descriptor(
  name='RequestStartAnonymousAuth',
  full_name='dialog.RequestStartAnonymousAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.RequestStartAnonymousAuth.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestStartAnonymousAuth.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestStartAnonymousAuth.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestStartAnonymousAuth.device_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestStartAnonymousAuth.device_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.RequestStartAnonymousAuth.time_zone', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestStartAnonymousAuth.preferred_languages', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1269,
  serialized_end=1597,
)


_REQUESTSTARTTOKENAUTH = _descriptor.Descriptor(
  name='RequestStartTokenAuth',
  full_name='dialog.RequestStartTokenAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.RequestStartTokenAuth.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestStartTokenAuth.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestStartTokenAuth.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestStartTokenAuth.device_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestStartTokenAuth.device_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.RequestStartTokenAuth.time_zone', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestStartTokenAuth.preferred_languages', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=1925,
)


_REQUESTSTARTUSERNAMEAUTH = _descriptor.Descriptor(
  name='RequestStartUsernameAuth',
  full_name='dialog.RequestStartUsernameAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='dialog.RequestStartUsernameAuth.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestStartUsernameAuth.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestStartUsernameAuth.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestStartUsernameAuth.device_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestStartUsernameAuth.device_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='dialog.RequestStartUsernameAuth.time_zone', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preferred_languages', full_name='dialog.RequestStartUsernameAuth.preferred_languages', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1928,
  serialized_end=2259,
)


_RESPONSESTARTUSERNAMEAUTH = _descriptor.Descriptor(
  name='ResponseStartUsernameAuth',
  full_name='dialog.ResponseStartUsernameAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.ResponseStartUsernameAuth.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_registered', full_name='dialog.ResponseStartUsernameAuth.is_registered', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2261,
  serialized_end=2368,
)


_REQUESTVALIDATECODE = _descriptor.Descriptor(
  name='RequestValidateCode',
  full_name='dialog.RequestValidateCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestValidateCode.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.RequestValidateCode.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=2489,
)


_REQUESTRESENDCODE = _descriptor.Descriptor(
  name='RequestResendCode',
  full_name='dialog.RequestResendCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestResendCode.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2491,
  serialized_end=2580,
)


_REQUESTVALIDATEPASSWORD = _descriptor.Descriptor(
  name='RequestValidatePassword',
  full_name='dialog.RequestValidatePassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestValidatePassword.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='dialog.RequestValidatePassword.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2582,
  serialized_end=2709,
)


_REQUESTGETOAUTH2PARAMS = _descriptor.Descriptor(
  name='RequestGetOAuth2Params',
  full_name='dialog.RequestGetOAuth2Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestGetOAuth2Params.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redirect_url', full_name='dialog.RequestGetOAuth2Params.redirect_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2712,
  serialized_end=2843,
)


_RESPONSEGETOAUTH2PARAMS = _descriptor.Descriptor(
  name='ResponseGetOAuth2Params',
  full_name='dialog.ResponseGetOAuth2Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_url', full_name='dialog.ResponseGetOAuth2Params.auth_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2845,
  serialized_end=2919,
)


_REQUESTCOMPLETEOAUTH2 = _descriptor.Descriptor(
  name='RequestCompleteOAuth2',
  full_name='dialog.RequestCompleteOAuth2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestCompleteOAuth2.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.RequestCompleteOAuth2.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2921,
  serialized_end=3042,
)


_REQUESTSIGNUP = _descriptor.Descriptor(
  name='RequestSignUp',
  full_name='dialog.RequestSignUp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_hash', full_name='dialog.RequestSignUp.transaction_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.RequestSignUp.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sex', full_name='dialog.RequestSignUp.sex', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='dialog.RequestSignUp.password', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3045,
  serialized_end=3262,
)


_RESPONSEAUTH = _descriptor.Descriptor(
  name='ResponseAuth',
  full_name='dialog.ResponseAuth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='dialog.ResponseAuth.user', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007compact'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='dialog.ResponseAuth.config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_hash', full_name='dialog.ResponseAuth.config_hash', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3265,
  serialized_end=3465,
)


_AUTHSESSION = _descriptor.Descriptor(
  name='AuthSession',
  full_name='dialog.AuthSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.AuthSession.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_holder', full_name='dialog.AuthSession.auth_holder', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.AuthSession.app_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_title', full_name='dialog.AuthSession.app_title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.AuthSession.device_title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_time', full_name='dialog.AuthSession.auth_time', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_location', full_name='dialog.AuthSession.auth_location', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='dialog.AuthSession.latitude', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='dialog.AuthSession.longitude', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3468,
  serialized_end=3862,
)


_REQUESTGETAUTHSESSIONS = _descriptor.Descriptor(
  name='RequestGetAuthSessions',
  full_name='dialog.RequestGetAuthSessions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3864,
  serialized_end=3918,
)


_RESPONSEGETAUTHSESSIONS = _descriptor.Descriptor(
  name='ResponseGetAuthSessions',
  full_name='dialog.ResponseGetAuthSessions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_auths', full_name='dialog.ResponseGetAuthSessions.user_auths', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3920,
  serialized_end=4017,
)


_REQUESTTERMINATESESSION = _descriptor.Descriptor(
  name='RequestTerminateSession',
  full_name='dialog.RequestTerminateSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestTerminateSession.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4019,
  serialized_end=4101,
)


_REQUESTTERMINATEALLSESSIONS = _descriptor.Descriptor(
  name='RequestTerminateAllSessions',
  full_name='dialog.RequestTerminateAllSessions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4103,
  serialized_end=4162,
)


_REQUESTSIGNOUT = _descriptor.Descriptor(
  name='RequestSignOut',
  full_name='dialog.RequestSignOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4164,
  serialized_end=4210,
)


_FORCERELOADFIELD = _descriptor.Descriptor(
  name='ForceReloadField',
  full_name='dialog.ForceReloadField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forceReloadDialogs', full_name='dialog.ForceReloadField.forceReloadDialogs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forceReloadContacts', full_name='dialog.ForceReloadField.forceReloadContacts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forceReloadHistory', full_name='dialog.ForceReloadField.forceReloadHistory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='dialog.ForceReloadField.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=4213,
  serialized_end=4415,
)


_FORCERELOADDIALOGS = _descriptor.Descriptor(
  name='ForceReloadDialogs',
  full_name='dialog.ForceReloadDialogs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4417,
  serialized_end=4437,
)


_FORCERELOADCONTACTS = _descriptor.Descriptor(
  name='ForceReloadContacts',
  full_name='dialog.ForceReloadContacts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4439,
  serialized_end=4460,
)


_FORCERELOADHISTORY = _descriptor.Descriptor(
  name='ForceReloadHistory',
  full_name='dialog.ForceReloadHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ForceReloadHistory.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4462,
  serialized_end=4525,
)


_UPDATEFORCERELOADSTATE = _descriptor.Descriptor(
  name='UpdateForceReloadState',
  full_name='dialog.UpdateForceReloadState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='dialog.UpdateForceReloadState.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4527,
  serialized_end=4608,
)


_REQUESTSIGNINOBSOLETE = _descriptor.Descriptor(
  name='RequestSignInObsolete',
  full_name='dialog.RequestSignInObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='dialog.RequestSignInObsolete.phone_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sms_hash', full_name='dialog.RequestSignInObsolete.sms_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sms_code', full_name='dialog.RequestSignInObsolete.sms_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestSignInObsolete.device_hash', index=3,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestSignInObsolete.device_title', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestSignInObsolete.app_id', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_key', full_name='dialog.RequestSignInObsolete.app_key', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4611,
  serialized_end=4898,
)


_REQUESTSIGNUPOBSOLETE = _descriptor.Descriptor(
  name='RequestSignUpObsolete',
  full_name='dialog.RequestSignUpObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='dialog.RequestSignUpObsolete.phone_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sms_hash', full_name='dialog.RequestSignUpObsolete.sms_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sms_code', full_name='dialog.RequestSignUpObsolete.sms_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.RequestSignUpObsolete.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_hash', full_name='dialog.RequestSignUpObsolete.device_hash', index=4,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestSignUpObsolete.device_title', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestSignUpObsolete.app_id', index=6,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_key', full_name='dialog.RequestSignUpObsolete.app_key', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_silent', full_name='dialog.RequestSignUpObsolete.is_silent', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4901,
  serialized_end=5236,
)


_REQUESTSENDAUTHCODEOBSOLETE = _descriptor.Descriptor(
  name='RequestSendAuthCodeObsolete',
  full_name='dialog.RequestSendAuthCodeObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='dialog.RequestSendAuthCodeObsolete.phone_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestSendAuthCodeObsolete.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestSendAuthCodeObsolete.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5239,
  serialized_end=5396,
)


_RESPONSESENDAUTHCODEOBSOLETE = _descriptor.Descriptor(
  name='ResponseSendAuthCodeObsolete',
  full_name='dialog.ResponseSendAuthCodeObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sms_hash', full_name='dialog.ResponseSendAuthCodeObsolete.sms_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_registered', full_name='dialog.ResponseSendAuthCodeObsolete.is_registered', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\032\n\030im.dlg.grpc.GrpcResponse'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5398,
  serialized_end=5500,
)


_REQUESTSENDAUTHCALLOBSOLETE = _descriptor.Descriptor(
  name='RequestSendAuthCallObsolete',
  full_name='dialog.RequestSendAuthCallObsolete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='dialog.RequestSendAuthCallObsolete.phone_number', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\t\n\007visible'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sms_hash', full_name='dialog.RequestSendAuthCallObsolete.sms_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006danger'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestSendAuthCallObsolete.app_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='dialog.RequestSendAuthCallObsolete.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\212\3520\010\n\006hidden'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\342?\031\n\027im.dlg.grpc.GrpcRequest'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5503,
  serialized_end=5692,
)

_REQUESTSTARTPHONEAUTH.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSESTARTPHONEAUTH.fields_by_name['activation_type'].enum_type = _PHONEACTIVATIONTYPE
_REQUESTSTARTEMAILAUTH.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSESTARTEMAILAUTH.fields_by_name['activation_type'].enum_type = _EMAILACTIVATIONTYPE
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSTARTTOKENAUTH.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['time_zone'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSIGNUP.fields_by_name['sex'].enum_type = users__pb2._SEX
_REQUESTSIGNUP.fields_by_name['password'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSEAUTH.fields_by_name['user'].message_type = users__pb2._USER
_RESPONSEAUTH.fields_by_name['config'].message_type = miscellaneous__pb2._CONFIG
_RESPONSEAUTH.fields_by_name['config_hash'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_AUTHSESSION.fields_by_name['auth_holder'].enum_type = _AUTHHOLDER
_AUTHSESSION.fields_by_name['latitude'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_AUTHSESSION.fields_by_name['longitude'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RESPONSEGETAUTHSESSIONS.fields_by_name['user_auths'].message_type = _AUTHSESSION
_FORCERELOADFIELD.fields_by_name['forceReloadDialogs'].message_type = _FORCERELOADDIALOGS
_FORCERELOADFIELD.fields_by_name['forceReloadContacts'].message_type = _FORCERELOADCONTACTS
_FORCERELOADFIELD.fields_by_name['forceReloadHistory'].message_type = _FORCERELOADHISTORY
_FORCERELOADFIELD.oneofs_by_name['body'].fields.append(
  _FORCERELOADFIELD.fields_by_name['forceReloadDialogs'])
_FORCERELOADFIELD.fields_by_name['forceReloadDialogs'].containing_oneof = _FORCERELOADFIELD.oneofs_by_name['body']
_FORCERELOADFIELD.oneofs_by_name['body'].fields.append(
  _FORCERELOADFIELD.fields_by_name['forceReloadContacts'])
_FORCERELOADFIELD.fields_by_name['forceReloadContacts'].containing_oneof = _FORCERELOADFIELD.oneofs_by_name['body']
_FORCERELOADFIELD.oneofs_by_name['body'].fields.append(
  _FORCERELOADFIELD.fields_by_name['forceReloadHistory'])
_FORCERELOADFIELD.fields_by_name['forceReloadHistory'].containing_oneof = _FORCERELOADFIELD.oneofs_by_name['body']
_FORCERELOADHISTORY.fields_by_name['peer'].message_type = peers__pb2._PEER
_UPDATEFORCERELOADSTATE.fields_by_name['fields'].message_type = _FORCERELOADFIELD
DESCRIPTOR.message_types_by_name['RequestStartPhoneAuth'] = _REQUESTSTARTPHONEAUTH
DESCRIPTOR.message_types_by_name['ResponseStartPhoneAuth'] = _RESPONSESTARTPHONEAUTH
DESCRIPTOR.message_types_by_name['RequestSendCodeByPhoneCall'] = _REQUESTSENDCODEBYPHONECALL
DESCRIPTOR.message_types_by_name['RequestStartEmailAuth'] = _REQUESTSTARTEMAILAUTH
DESCRIPTOR.message_types_by_name['ResponseStartEmailAuth'] = _RESPONSESTARTEMAILAUTH
DESCRIPTOR.message_types_by_name['RequestStartAnonymousAuth'] = _REQUESTSTARTANONYMOUSAUTH
DESCRIPTOR.message_types_by_name['RequestStartTokenAuth'] = _REQUESTSTARTTOKENAUTH
DESCRIPTOR.message_types_by_name['RequestStartUsernameAuth'] = _REQUESTSTARTUSERNAMEAUTH
DESCRIPTOR.message_types_by_name['ResponseStartUsernameAuth'] = _RESPONSESTARTUSERNAMEAUTH
DESCRIPTOR.message_types_by_name['RequestValidateCode'] = _REQUESTVALIDATECODE
DESCRIPTOR.message_types_by_name['RequestResendCode'] = _REQUESTRESENDCODE
DESCRIPTOR.message_types_by_name['RequestValidatePassword'] = _REQUESTVALIDATEPASSWORD
DESCRIPTOR.message_types_by_name['RequestGetOAuth2Params'] = _REQUESTGETOAUTH2PARAMS
DESCRIPTOR.message_types_by_name['ResponseGetOAuth2Params'] = _RESPONSEGETOAUTH2PARAMS
DESCRIPTOR.message_types_by_name['RequestCompleteOAuth2'] = _REQUESTCOMPLETEOAUTH2
DESCRIPTOR.message_types_by_name['RequestSignUp'] = _REQUESTSIGNUP
DESCRIPTOR.message_types_by_name['ResponseAuth'] = _RESPONSEAUTH
DESCRIPTOR.message_types_by_name['AuthSession'] = _AUTHSESSION
DESCRIPTOR.message_types_by_name['RequestGetAuthSessions'] = _REQUESTGETAUTHSESSIONS
DESCRIPTOR.message_types_by_name['ResponseGetAuthSessions'] = _RESPONSEGETAUTHSESSIONS
DESCRIPTOR.message_types_by_name['RequestTerminateSession'] = _REQUESTTERMINATESESSION
DESCRIPTOR.message_types_by_name['RequestTerminateAllSessions'] = _REQUESTTERMINATEALLSESSIONS
DESCRIPTOR.message_types_by_name['RequestSignOut'] = _REQUESTSIGNOUT
DESCRIPTOR.message_types_by_name['ForceReloadField'] = _FORCERELOADFIELD
DESCRIPTOR.message_types_by_name['ForceReloadDialogs'] = _FORCERELOADDIALOGS
DESCRIPTOR.message_types_by_name['ForceReloadContacts'] = _FORCERELOADCONTACTS
DESCRIPTOR.message_types_by_name['ForceReloadHistory'] = _FORCERELOADHISTORY
DESCRIPTOR.message_types_by_name['UpdateForceReloadState'] = _UPDATEFORCERELOADSTATE
DESCRIPTOR.message_types_by_name['RequestSignInObsolete'] = _REQUESTSIGNINOBSOLETE
DESCRIPTOR.message_types_by_name['RequestSignUpObsolete'] = _REQUESTSIGNUPOBSOLETE
DESCRIPTOR.message_types_by_name['RequestSendAuthCodeObsolete'] = _REQUESTSENDAUTHCODEOBSOLETE
DESCRIPTOR.message_types_by_name['ResponseSendAuthCodeObsolete'] = _RESPONSESENDAUTHCODEOBSOLETE
DESCRIPTOR.message_types_by_name['RequestSendAuthCallObsolete'] = _REQUESTSENDAUTHCALLOBSOLETE
DESCRIPTOR.enum_types_by_name['PhoneActivationType'] = _PHONEACTIVATIONTYPE
DESCRIPTOR.enum_types_by_name['EmailActivationType'] = _EMAILACTIVATIONTYPE
DESCRIPTOR.enum_types_by_name['AuthHolder'] = _AUTHHOLDER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestStartPhoneAuth = _reflection.GeneratedProtocolMessageType('RequestStartPhoneAuth', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSTARTPHONEAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStartPhoneAuth)
  ))
_sym_db.RegisterMessage(RequestStartPhoneAuth)

ResponseStartPhoneAuth = _reflection.GeneratedProtocolMessageType('ResponseStartPhoneAuth', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSESTARTPHONEAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseStartPhoneAuth)
  ))
_sym_db.RegisterMessage(ResponseStartPhoneAuth)

RequestSendCodeByPhoneCall = _reflection.GeneratedProtocolMessageType('RequestSendCodeByPhoneCall', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSENDCODEBYPHONECALL,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSendCodeByPhoneCall)
  ))
_sym_db.RegisterMessage(RequestSendCodeByPhoneCall)

RequestStartEmailAuth = _reflection.GeneratedProtocolMessageType('RequestStartEmailAuth', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSTARTEMAILAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStartEmailAuth)
  ))
_sym_db.RegisterMessage(RequestStartEmailAuth)

ResponseStartEmailAuth = _reflection.GeneratedProtocolMessageType('ResponseStartEmailAuth', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSESTARTEMAILAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseStartEmailAuth)
  ))
_sym_db.RegisterMessage(ResponseStartEmailAuth)

RequestStartAnonymousAuth = _reflection.GeneratedProtocolMessageType('RequestStartAnonymousAuth', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSTARTANONYMOUSAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStartAnonymousAuth)
  ))
_sym_db.RegisterMessage(RequestStartAnonymousAuth)

RequestStartTokenAuth = _reflection.GeneratedProtocolMessageType('RequestStartTokenAuth', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSTARTTOKENAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStartTokenAuth)
  ))
_sym_db.RegisterMessage(RequestStartTokenAuth)

RequestStartUsernameAuth = _reflection.GeneratedProtocolMessageType('RequestStartUsernameAuth', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSTARTUSERNAMEAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStartUsernameAuth)
  ))
_sym_db.RegisterMessage(RequestStartUsernameAuth)

ResponseStartUsernameAuth = _reflection.GeneratedProtocolMessageType('ResponseStartUsernameAuth', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSESTARTUSERNAMEAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseStartUsernameAuth)
  ))
_sym_db.RegisterMessage(ResponseStartUsernameAuth)

RequestValidateCode = _reflection.GeneratedProtocolMessageType('RequestValidateCode', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTVALIDATECODE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestValidateCode)
  ))
_sym_db.RegisterMessage(RequestValidateCode)

RequestResendCode = _reflection.GeneratedProtocolMessageType('RequestResendCode', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTRESENDCODE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestResendCode)
  ))
_sym_db.RegisterMessage(RequestResendCode)

RequestValidatePassword = _reflection.GeneratedProtocolMessageType('RequestValidatePassword', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTVALIDATEPASSWORD,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestValidatePassword)
  ))
_sym_db.RegisterMessage(RequestValidatePassword)

RequestGetOAuth2Params = _reflection.GeneratedProtocolMessageType('RequestGetOAuth2Params', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETOAUTH2PARAMS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetOAuth2Params)
  ))
_sym_db.RegisterMessage(RequestGetOAuth2Params)

ResponseGetOAuth2Params = _reflection.GeneratedProtocolMessageType('ResponseGetOAuth2Params', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETOAUTH2PARAMS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetOAuth2Params)
  ))
_sym_db.RegisterMessage(ResponseGetOAuth2Params)

RequestCompleteOAuth2 = _reflection.GeneratedProtocolMessageType('RequestCompleteOAuth2', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTCOMPLETEOAUTH2,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCompleteOAuth2)
  ))
_sym_db.RegisterMessage(RequestCompleteOAuth2)

RequestSignUp = _reflection.GeneratedProtocolMessageType('RequestSignUp', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSIGNUP,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSignUp)
  ))
_sym_db.RegisterMessage(RequestSignUp)

ResponseAuth = _reflection.GeneratedProtocolMessageType('ResponseAuth', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEAUTH,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseAuth)
  ))
_sym_db.RegisterMessage(ResponseAuth)

AuthSession = _reflection.GeneratedProtocolMessageType('AuthSession', (_message.Message,), dict(
  DESCRIPTOR = _AUTHSESSION,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AuthSession)
  ))
_sym_db.RegisterMessage(AuthSession)

RequestGetAuthSessions = _reflection.GeneratedProtocolMessageType('RequestGetAuthSessions', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTGETAUTHSESSIONS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetAuthSessions)
  ))
_sym_db.RegisterMessage(RequestGetAuthSessions)

ResponseGetAuthSessions = _reflection.GeneratedProtocolMessageType('ResponseGetAuthSessions', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEGETAUTHSESSIONS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetAuthSessions)
  ))
_sym_db.RegisterMessage(ResponseGetAuthSessions)

RequestTerminateSession = _reflection.GeneratedProtocolMessageType('RequestTerminateSession', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTTERMINATESESSION,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestTerminateSession)
  ))
_sym_db.RegisterMessage(RequestTerminateSession)

RequestTerminateAllSessions = _reflection.GeneratedProtocolMessageType('RequestTerminateAllSessions', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTTERMINATEALLSESSIONS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestTerminateAllSessions)
  ))
_sym_db.RegisterMessage(RequestTerminateAllSessions)

RequestSignOut = _reflection.GeneratedProtocolMessageType('RequestSignOut', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSIGNOUT,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSignOut)
  ))
_sym_db.RegisterMessage(RequestSignOut)

ForceReloadField = _reflection.GeneratedProtocolMessageType('ForceReloadField', (_message.Message,), dict(
  DESCRIPTOR = _FORCERELOADFIELD,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ForceReloadField)
  ))
_sym_db.RegisterMessage(ForceReloadField)

ForceReloadDialogs = _reflection.GeneratedProtocolMessageType('ForceReloadDialogs', (_message.Message,), dict(
  DESCRIPTOR = _FORCERELOADDIALOGS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ForceReloadDialogs)
  ))
_sym_db.RegisterMessage(ForceReloadDialogs)

ForceReloadContacts = _reflection.GeneratedProtocolMessageType('ForceReloadContacts', (_message.Message,), dict(
  DESCRIPTOR = _FORCERELOADCONTACTS,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ForceReloadContacts)
  ))
_sym_db.RegisterMessage(ForceReloadContacts)

ForceReloadHistory = _reflection.GeneratedProtocolMessageType('ForceReloadHistory', (_message.Message,), dict(
  DESCRIPTOR = _FORCERELOADHISTORY,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ForceReloadHistory)
  ))
_sym_db.RegisterMessage(ForceReloadHistory)

UpdateForceReloadState = _reflection.GeneratedProtocolMessageType('UpdateForceReloadState', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEFORCERELOADSTATE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateForceReloadState)
  ))
_sym_db.RegisterMessage(UpdateForceReloadState)

RequestSignInObsolete = _reflection.GeneratedProtocolMessageType('RequestSignInObsolete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSIGNINOBSOLETE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSignInObsolete)
  ))
_sym_db.RegisterMessage(RequestSignInObsolete)

RequestSignUpObsolete = _reflection.GeneratedProtocolMessageType('RequestSignUpObsolete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSIGNUPOBSOLETE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSignUpObsolete)
  ))
_sym_db.RegisterMessage(RequestSignUpObsolete)

RequestSendAuthCodeObsolete = _reflection.GeneratedProtocolMessageType('RequestSendAuthCodeObsolete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSENDAUTHCODEOBSOLETE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSendAuthCodeObsolete)
  ))
_sym_db.RegisterMessage(RequestSendAuthCodeObsolete)

ResponseSendAuthCodeObsolete = _reflection.GeneratedProtocolMessageType('ResponseSendAuthCodeObsolete', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSESENDAUTHCODEOBSOLETE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSendAuthCodeObsolete)
  ))
_sym_db.RegisterMessage(ResponseSendAuthCodeObsolete)

RequestSendAuthCallObsolete = _reflection.GeneratedProtocolMessageType('RequestSendAuthCallObsolete', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTSENDAUTHCALLOBSOLETE,
  __module__ = 'authentication_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSendAuthCallObsolete)
  ))
_sym_db.RegisterMessage(RequestSendAuthCallObsolete)


DESCRIPTOR._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['phone_number']._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['app_id']._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['api_key']._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['device_hash']._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['device_title']._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['time_zone']._options = None
_REQUESTSTARTPHONEAUTH.fields_by_name['preferred_languages']._options = None
_REQUESTSTARTPHONEAUTH._options = None
_RESPONSESTARTPHONEAUTH._options = None
_REQUESTSENDCODEBYPHONECALL.fields_by_name['transaction_hash']._options = None
_REQUESTSENDCODEBYPHONECALL._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['email']._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['app_id']._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['api_key']._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['device_hash']._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['device_title']._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['time_zone']._options = None
_REQUESTSTARTEMAILAUTH.fields_by_name['preferred_languages']._options = None
_REQUESTSTARTEMAILAUTH._options = None
_RESPONSESTARTEMAILAUTH._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['name']._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['app_id']._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['api_key']._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['device_hash']._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['device_title']._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['time_zone']._options = None
_REQUESTSTARTANONYMOUSAUTH.fields_by_name['preferred_languages']._options = None
_REQUESTSTARTANONYMOUSAUTH._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['token']._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['app_id']._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['api_key']._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['device_hash']._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['device_title']._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['time_zone']._options = None
_REQUESTSTARTTOKENAUTH.fields_by_name['preferred_languages']._options = None
_REQUESTSTARTTOKENAUTH._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['username']._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['app_id']._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['api_key']._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['device_hash']._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['device_title']._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['time_zone']._options = None
_REQUESTSTARTUSERNAMEAUTH.fields_by_name['preferred_languages']._options = None
_REQUESTSTARTUSERNAMEAUTH._options = None
_RESPONSESTARTUSERNAMEAUTH._options = None
_REQUESTVALIDATECODE.fields_by_name['transaction_hash']._options = None
_REQUESTVALIDATECODE.fields_by_name['code']._options = None
_REQUESTVALIDATECODE._options = None
_REQUESTRESENDCODE.fields_by_name['transaction_hash']._options = None
_REQUESTRESENDCODE._options = None
_REQUESTVALIDATEPASSWORD.fields_by_name['transaction_hash']._options = None
_REQUESTVALIDATEPASSWORD.fields_by_name['password']._options = None
_REQUESTVALIDATEPASSWORD._options = None
_REQUESTGETOAUTH2PARAMS.fields_by_name['transaction_hash']._options = None
_REQUESTGETOAUTH2PARAMS.fields_by_name['redirect_url']._options = None
_REQUESTGETOAUTH2PARAMS._options = None
_RESPONSEGETOAUTH2PARAMS._options = None
_REQUESTCOMPLETEOAUTH2.fields_by_name['transaction_hash']._options = None
_REQUESTCOMPLETEOAUTH2.fields_by_name['code']._options = None
_REQUESTCOMPLETEOAUTH2._options = None
_REQUESTSIGNUP.fields_by_name['transaction_hash']._options = None
_REQUESTSIGNUP.fields_by_name['name']._options = None
_REQUESTSIGNUP.fields_by_name['sex']._options = None
_REQUESTSIGNUP.fields_by_name['password']._options = None
_REQUESTSIGNUP._options = None
_RESPONSEAUTH.fields_by_name['user']._options = None
_RESPONSEAUTH.fields_by_name['config']._options = None
_RESPONSEAUTH.fields_by_name['config_hash']._options = None
_RESPONSEAUTH._options = None
_AUTHSESSION.fields_by_name['id']._options = None
_AUTHSESSION.fields_by_name['auth_holder']._options = None
_AUTHSESSION.fields_by_name['app_id']._options = None
_AUTHSESSION.fields_by_name['app_title']._options = None
_AUTHSESSION.fields_by_name['device_title']._options = None
_AUTHSESSION.fields_by_name['auth_time']._options = None
_AUTHSESSION.fields_by_name['auth_location']._options = None
_AUTHSESSION.fields_by_name['latitude']._options = None
_AUTHSESSION.fields_by_name['longitude']._options = None
_REQUESTGETAUTHSESSIONS._options = None
_RESPONSEGETAUTHSESSIONS._options = None
_REQUESTTERMINATESESSION.fields_by_name['id']._options = None
_REQUESTTERMINATESESSION._options = None
_REQUESTTERMINATEALLSESSIONS._options = None
_REQUESTSIGNOUT._options = None
_FORCERELOADHISTORY.fields_by_name['peer']._options = None
_UPDATEFORCERELOADSTATE.fields_by_name['fields']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['phone_number']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['sms_hash']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['sms_code']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['device_hash']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['device_title']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['app_id']._options = None
_REQUESTSIGNINOBSOLETE.fields_by_name['app_key']._options = None
_REQUESTSIGNINOBSOLETE._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['phone_number']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['sms_hash']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['sms_code']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['name']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['device_hash']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['device_title']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['app_id']._options = None
_REQUESTSIGNUPOBSOLETE.fields_by_name['app_key']._options = None
_REQUESTSIGNUPOBSOLETE._options = None
_REQUESTSENDAUTHCODEOBSOLETE.fields_by_name['phone_number']._options = None
_REQUESTSENDAUTHCODEOBSOLETE.fields_by_name['app_id']._options = None
_REQUESTSENDAUTHCODEOBSOLETE.fields_by_name['api_key']._options = None
_REQUESTSENDAUTHCODEOBSOLETE._options = None
_RESPONSESENDAUTHCODEOBSOLETE._options = None
_REQUESTSENDAUTHCALLOBSOLETE.fields_by_name['phone_number']._options = None
_REQUESTSENDAUTHCALLOBSOLETE.fields_by_name['sms_hash']._options = None
_REQUESTSENDAUTHCALLOBSOLETE.fields_by_name['app_id']._options = None
_REQUESTSENDAUTHCALLOBSOLETE.fields_by_name['api_key']._options = None
_REQUESTSENDAUTHCALLOBSOLETE._options = None

_AUTHENTICATION = _descriptor.ServiceDescriptor(
  name='Authentication',
  full_name='dialog.Authentication',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=6061,
  serialized_end=8643,
  methods=[
  _descriptor.MethodDescriptor(
    name='StartPhoneAuth',
    full_name='dialog.Authentication.StartPhoneAuth',
    index=0,
    containing_service=None,
    input_type=_REQUESTSTARTPHONEAUTH,
    output_type=_RESPONSESTARTPHONEAUTH,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Authentication/StartPhoneAuth:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SendCodeByPhoneCall',
    full_name='dialog.Authentication.SendCodeByPhoneCall',
    index=1,
    containing_service=None,
    input_type=_REQUESTSENDCODEBYPHONECALL,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\0020\"+/v1/grpc/Authentication/SendCodeByPhoneCall:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='StartEmailAuth',
    full_name='dialog.Authentication.StartEmailAuth',
    index=2,
    containing_service=None,
    input_type=_REQUESTSTARTEMAILAUTH,
    output_type=_RESPONSESTARTEMAILAUTH,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Authentication/StartEmailAuth:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='StartAnonymousAuth',
    full_name='dialog.Authentication.StartAnonymousAuth',
    index=3,
    containing_service=None,
    input_type=_REQUESTSTARTANONYMOUSAUTH,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002/\"*/v1/grpc/Authentication/StartAnonymousAuth:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='StartTokenAuth',
    full_name='dialog.Authentication.StartTokenAuth',
    index=4,
    containing_service=None,
    input_type=_REQUESTSTARTTOKENAUTH,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Authentication/StartTokenAuth:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='StartUsernameAuth',
    full_name='dialog.Authentication.StartUsernameAuth',
    index=5,
    containing_service=None,
    input_type=_REQUESTSTARTUSERNAMEAUTH,
    output_type=_RESPONSESTARTUSERNAMEAUTH,
    serialized_options=_b('\202\323\344\223\002.\")/v1/grpc/Authentication/StartUsernameAuth:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ValidateCode',
    full_name='dialog.Authentication.ValidateCode',
    index=6,
    containing_service=None,
    input_type=_REQUESTVALIDATECODE,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002)\"$/v1/grpc/Authentication/ValidateCode:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ResendCode',
    full_name='dialog.Authentication.ResendCode',
    index=7,
    containing_service=None,
    input_type=_REQUESTRESENDCODE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002\'\"\"/v1/grpc/Authentication/ResendCode:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ValidatePassword',
    full_name='dialog.Authentication.ValidatePassword',
    index=8,
    containing_service=None,
    input_type=_REQUESTVALIDATEPASSWORD,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002-\"(/v1/grpc/Authentication/ValidatePassword:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetOAuth2Params',
    full_name='dialog.Authentication.GetOAuth2Params',
    index=9,
    containing_service=None,
    input_type=_REQUESTGETOAUTH2PARAMS,
    output_type=_RESPONSEGETOAUTH2PARAMS,
    serialized_options=_b('\202\323\344\223\002,\"\'/v1/grpc/Authentication/GetOAuth2Params:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CompleteOAuth2',
    full_name='dialog.Authentication.CompleteOAuth2',
    index=10,
    containing_service=None,
    input_type=_REQUESTCOMPLETEOAUTH2,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Authentication/CompleteOAuth2:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SignUp',
    full_name='dialog.Authentication.SignUp',
    index=11,
    containing_service=None,
    input_type=_REQUESTSIGNUP,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/grpc/Authentication/SignUp:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthSessions',
    full_name='dialog.Authentication.GetAuthSessions',
    index=12,
    containing_service=None,
    input_type=_REQUESTGETAUTHSESSIONS,
    output_type=_RESPONSEGETAUTHSESSIONS,
    serialized_options=_b('\202\323\344\223\002,\"\'/v1/grpc/Authentication/GetAuthSessions:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='TerminateSession',
    full_name='dialog.Authentication.TerminateSession',
    index=13,
    containing_service=None,
    input_type=_REQUESTTERMINATESESSION,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002-\"(/v1/grpc/Authentication/TerminateSession:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='TerminateAllSessions',
    full_name='dialog.Authentication.TerminateAllSessions',
    index=14,
    containing_service=None,
    input_type=_REQUESTTERMINATEALLSESSIONS,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\0021\",/v1/grpc/Authentication/TerminateAllSessions:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SignOut',
    full_name='dialog.Authentication.SignOut',
    index=15,
    containing_service=None,
    input_type=_REQUESTSIGNOUT,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\002$\"\037/v1/grpc/Authentication/SignOut:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SignInObsolete',
    full_name='dialog.Authentication.SignInObsolete',
    index=16,
    containing_service=None,
    input_type=_REQUESTSIGNINOBSOLETE,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Authentication/SignInObsolete:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SignUpObsolete',
    full_name='dialog.Authentication.SignUpObsolete',
    index=17,
    containing_service=None,
    input_type=_REQUESTSIGNUPOBSOLETE,
    output_type=_RESPONSEAUTH,
    serialized_options=_b('\202\323\344\223\002+\"&/v1/grpc/Authentication/SignUpObsolete:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SendAuthCodeObsolete',
    full_name='dialog.Authentication.SendAuthCodeObsolete',
    index=18,
    containing_service=None,
    input_type=_REQUESTSENDAUTHCODEOBSOLETE,
    output_type=_RESPONSESENDAUTHCODEOBSOLETE,
    serialized_options=_b('\202\323\344\223\0021\",/v1/grpc/Authentication/SendAuthCodeObsolete:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SendAuthCallObsolete',
    full_name='dialog.Authentication.SendAuthCallObsolete',
    index=19,
    containing_service=None,
    input_type=_REQUESTSENDAUTHCALLOBSOLETE,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=_b('\202\323\344\223\0021\",/v1/grpc/Authentication/SendAuthCallObsolete:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHENTICATION)

DESCRIPTOR.services_by_name['Authentication'] = _AUTHENTICATION

# @@protoc_insertion_point(module_scope)
